# unitorch.cli.models.swin

## SwinProcessor

!!! tip
    **`core/process/swin`** is the section for configuration of SwinProcessor.

::: unitorch.cli.models.swin.SwinProcessor

## SwinForImageClassification

!!! tip
    **`core/model/classification/swin`** is the section for configuration of SwinForImageClassification.

::: unitorch.cli.models.swin.SwinForImageClassification
